###################################################
### chunk number 1: preliminary
###################################################
options("prompt" = "R> ", "continue" = "+ ")


###################################################
### chunk number 2: 
###################################################
library("analogue")


###################################################
### chunk number 3: 
###################################################
data(swapdiat, swappH, rlgh, package = "analogue")


###################################################
### chunk number 4: 
###################################################
dat <- join(swapdiat, rlgh, verbose = TRUE)


###################################################
### chunk number 5: 
###################################################
swapdiat <- dat$swapdiat / 100
rlgh <- dat$rlgh / 100


###################################################
### chunk number 6: 
###################################################
swap.mat <- mat(swapdiat, swappH, method = "SQchord")


###################################################
### chunk number 7: 
###################################################
swap.mat


###################################################
### chunk number 8: 
###################################################
summary(swap.mat)


###################################################
### chunk number 9: plot_mat
###################################################
opar <- par(mfrow = c(2,2))
plot(swap.mat)
par(opar)


###################################################
### chunk number 10: 
###################################################
getK(swap.mat)


###################################################
### chunk number 11: 
###################################################
opar <- par(mfrow = c(2,2))
plot(swap.mat)
par(opar)


###################################################
### chunk number 12: 
###################################################
rlgh.mat <- predict(swap.mat, rlgh, k = 10)
rlgh.mat


###################################################
### chunk number 13: plot_recon
###################################################
reconPlot(rlgh.mat, use.labels = TRUE, ylab = "pH", xlab = "Depth (cm.)")


###################################################
### chunk number 14: 
###################################################
reconPlot(rlgh.mat, use.labels = TRUE, ylab = "pH", xlab = "Depth (cm.)")


###################################################
### chunk number 15: 
###################################################
rlgh.mdc <- minDC(rlgh.mat)


###################################################
### chunk number 16: plot_minDC
###################################################
plot(rlgh.mdc, use.labels = TRUE, xlab = "Depth (cm.)")


###################################################
### chunk number 17: 
###################################################
plot(rlgh.mdc, use.labels = TRUE, xlab = "Depth (cm.)")


###################################################
### chunk number 18: 
###################################################
rlgh.ref <- rlgh[25:37, ]
swap.ana <- analog(swapdiat, rlgh.ref, method = "chord")
swap.ana


###################################################
### chunk number 19: cma
###################################################
swap.cma <- cma(swap.ana)
swap.cma


###################################################
### chunk number 20: 
###################################################
cma(swap.ana, cutoff = 0.5)


###################################################
### chunk number 21: plot_cma
###################################################
plot(swap.cma)


###################################################
### chunk number 22: 
###################################################
plot(swap.cma)


###################################################
### chunk number 23: plot_dissim
###################################################
plot(dissim(swap.ana))


###################################################
### chunk number 24: 
###################################################
plot(dissim(swap.ana))


###################################################
### chunk number 25: mcarlo
###################################################
swap.mc <- mcarlo(swap.ana)
swap.mc


###################################################
### chunk number 26: bootstrap
###################################################
set.seed(1234)
swap.boot <- bootstrap(swap.mat, n.boot = 100)
swap.boot


###################################################
### chunk number 27: rmsep
###################################################
RMSEP(swap.boot, type = "standard")


###################################################
### chunk number 28: 
###################################################
getK(swap.boot)
setK(swap.mat) <- getK(swap.boot)


###################################################
### chunk number 29: clust_sites
###################################################
clust <- hclust(as.dist(swap.mat$Dij), method = "ward") #$
grps <- cutree(clust, k = 12)


###################################################
### chunk number 30: roc
###################################################
swap.roc <- roc(swap.mat, groups = grps)
swap.roc


###################################################
### chunk number 31: plot_roc
###################################################
opar <- par(mfrow = c(2,2))
plot(swap.roc)
par(opar)


###################################################
### chunk number 32: 
###################################################
opar <- par(mfrow = c(2,2))
plot(swap.roc)
par(opar)


###################################################
### chunk number 33: 
###################################################
dists1 <- distance(swapdiat, method = "bray")
dists2 <- distance(swapdiat, rlgh, method = "bray")


###################################################
### chunk number 34: sample_specific
###################################################
set.seed(1234)
rlgh.boot <- predict(swap.mat, rlgh, bootstrap = TRUE, n.boot = 100)
reconPlot(rlgh.boot, use.labels = TRUE, ylab = "pH", xlab = "Depth (cm.)",
          display.error = "bars", predictions = "bootstrap")


###################################################
### chunk number 35: 
###################################################
reconPlot(rlgh.boot, use.labels = TRUE, ylab = "pH", xlab = "Depth (cm.)",
          display.error = "bars", predictions = "bootstrap")


###################################################
### chunk number 36: 
###################################################
set.seed(1234)
want <- sample(1:nrow(swapdiat), 67, replace = FALSE)
train <- swapdiat[-want, ]
train.env <- swappH[-want]
test <- swapdiat[want, ]
test.env <- swappH[want]


###################################################
### chunk number 37: testset_boot
###################################################
train.mat <- mat(train, train.env, method = "SQchord")
test.boot <- bootstrap(train.mat, newdata = test, 
                       newenv = test.env, n.boot = 100)
test.boot


###################################################
### chunk number 38: 
###################################################
set.seed(9876)
want <- sample(nrow(test), 40)
opti <- test[-want, ]
opti.env <- test.env[-want]
test <- test[want, ]
test.env <- test.env[want]


###################################################
### chunk number 39: opti
###################################################
opti.boot <- bootstrap(train.mat, newdata = opti, newenv = opti.env, n.boot = 100)
opti.boot


###################################################
### chunk number 40: 
###################################################
use.k <- getK(opti.boot, prediction = TRUE, which = "model")
test.boot <- bootstrap(train.mat, newdata = test, newenv = test.env, k = use.k, n.boot = 100)
test.boot


###################################################
### chunk number 41: subsetting
###################################################
dat <- join(swapdiat, rlgh, split = FALSE)
max.abb <- apply(dat, 2, max)
n.occ <- colSums(dat > 0)
spp.want <- which(max.abb >= 0.02 & n.occ >= 5)
swapdiat2 <- swapdiat[, spp.want]
rlgh2 <- rlgh[, spp.want]


###################################################
### chunk number 42: mat_inferred
###################################################
plot(swap.mat, which = 1)


###################################################
### chunk number 43: 
###################################################
plot(swap.mat, which = 1)


###################################################
### chunk number 44: mat_resid
###################################################
plot(swap.mat, which = 2)


###################################################
### chunk number 45: 
###################################################
plot(swap.mat, which = 2)


###################################################
### chunk number 46: scree
###################################################
screeplot(swap.boot)


###################################################
### chunk number 47: 
###################################################
screeplot(swap.boot)


